==> haskell-hls-alternate-number-format-plugin-2.1.0.0-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-alternate-number-format-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-alternate-number-format-plugin-2.1.0.0-IomMhOSCQmqL7Qtz39LeNR

key:
    hls-alternate-number-format-plugin-2.1.0.0-IomMhOSCQmqL7Qtz39LeNR

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  21f15bc2b61a2d156453efa295c819eb
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-2.1.0.0-IomMhOSCQmqL7Qtz39LeNR

depends:
    aeson-2.1.2.1-J19dEw13kUOF5hLEOQVj2r base-4.17.2.1 containers-0.6.7
    extra-1.7.16-DOwdXWfQN4O1hxxIx77WWM ghc-boot-th-9.4.8
    ghcide-2.1.0.0-K4I3jk3yba99VwyVuyCjAK
    hie-compat-0.3.1.2-IkeVSMKPoXJ5qEiKo06jB7
    hls-graph-2.1.0.0-CIS4kLyYlgf1HXugtgYd9b
    hls-plugin-api-2.1.0.0-43mPtPTqePgGg2z2qphciN
    lens-5.3.1-6s7OGBiqW0t1WJAI91dKgc
    lsp-2.1.0.0-KLUMztUaLnzIKmGW0jGo29 mtl-2.2.2
    regex-tdfa-1.3.2.4-It8kSvUca7pIUIDpZynqfd
    syb-0.7.3-6VXQKmiHaWYG9qlQr6p3GQ text-2.0.2
    unordered-containers-0.2.20-1i1FNKzvn6TI2R1AzcNrcz

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-alternate-number-format-plugin-2.1.0.0-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-alternate-number-format-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-alternate-number-format-plugin-2.1.0.0-Lcwm9snW8EN5qX9W92nH70

key:
    hls-alternate-number-format-plugin-2.1.0.0-Lcwm9snW8EN5qX9W92nH70

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  88e8b659828d825ba10394c6a53df129
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-2.1.0.0-Lcwm9snW8EN5qX9W92nH70

depends:
    aeson-2.1.2.1-wY4CXNP4Ti6TCaMY1tyMf base-4.17.2.1 containers-0.6.7
    extra-1.7.16-BWp1326BLeAsZES8r4M0Z ghc-boot-th-9.4.8
    ghcide-2.1.0.0-8B4LlBejCTbF31o6kR9tn
    hie-compat-0.3.1.2-IkeVSMKPoXJ5qEiKo06jB7
    hls-graph-2.1.0.0-FkSiN9VQ3X6H4SCvfBtEL2
    hls-plugin-api-2.1.0.0-EhaL6VhspD6K8f7FAV23oq
    lens-5.3.1-HP4sFfbh3y9B4laWgY1DEm
    lsp-2.1.0.0-2r7Z29fE5rZ2FQGC2gdzUu mtl-2.2.2
    regex-tdfa-1.3.2.4-6komq1p5pxY9JApKLJtftx
    syb-0.7.3-BQUcn35RmaZ45KQPDd3rN text-2.0.2
    unordered-containers-0.2.20-BdnqkwZm9bx6ocoMK9HG74

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
